This library extends eth_portfolio with additional functionality centered around producing financial reports for DAOs and other on-chain orgs.

## Installation

```bash
pip install dao-treasury
```

## Prerequisites

You must have a [brownie network](https://eth-brownie.readthedocs.io/en/stable/network-management.html) configured to use your RPC.
You will also need [Docker](https://www.docker.com/get-started/) installed on your system.
